# Animation Options

Animation commands are used to create and control object-based and image-based animations in the viewport.

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Animation
        :recursive:
```
